@@ -9,7 +9,7 @@ if grep 'localhost:4000' *.md _posts/*.md; then
 fi
 
 if [ "x$(git status --porcelain)" != "x" ]; then
-  echo -n "git repo has uncommited changes.  Continue anyway? (y/N) " >&2
+  echo -n "git repo has uncommitted changes.  Continue anyway? (y/N) " >&2
   read -n 1 YESNO
   echo >&2
   if [ "x$YESNO" != xy ]; then
